@@ -181,7 +181,7 @@ class AmiPipelineLib(
             username=username,
         )
 
-        jsii.create(AmiPipelineLib, self, [scope, id, pipeline_config, component_deps_config, component_builder, optional_params])
+        jsii.create(self.__class__, self, [scope, id, pipeline_config, component_deps_config, component_builder, optional_params])
 
     @jsii.member(jsii_name="createCleanerTask")
     def create_cleaner_task(self) -> None:
@@ -452,7 +452,7 @@ class ArnComponentRef(
         :param arn: -
         :param name: -
         '''
-        jsii.create(ArnComponentRef, self, [arn, name])
+        jsii.create(self.__class__, self, [arn, name])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="name")
@@ -486,7 +486,7 @@ class ComponentBuilder(
         :param scope: -
         :param component_defs: -
         '''
-        jsii.create(ComponentBuilder, self, [scope, component_defs])
+        jsii.create(self.__class__, self, [scope, component_defs])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cacheDir")
@@ -670,7 +670,7 @@ class ComponentSynchronizer(
     '''Ensures that component dependencies are downloaded and available.'''
 
     def __init__(self) -> None:
-        jsii.create(ComponentSynchronizer, self, [])
+        jsii.create(self.__class__, self, [])
 
     @jsii.member(jsii_name="synchronize")
     def synchronize(
@@ -700,7 +700,7 @@ class PipelineBuilder(
         '''
         :param config: -
         '''
-        jsii.create(PipelineBuilder, self, [config])
+        jsii.create(self.__class__, self, [config])
 
     @jsii.member(jsii_name="create")
     def create(
@@ -810,7 +810,7 @@ class SlackNotification(
         :param slack_config: -
         :param recipename: -
         '''
-        jsii.create(SlackNotification, self, [scope, id, sns_topic, slack_config, recipename])
+        jsii.create(self.__class__, self, [scope, id, sns_topic, slack_config, recipename])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="snsTopic")
@@ -835,7 +835,7 @@ class SourceAction(
         :param source_output: -
         :param action: -
         '''
-        jsii.create(SourceAction, self, [source_output, action])
+        jsii.create(self.__class__, self, [source_output, action])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="action")
@@ -871,7 +871,7 @@ class SourceActionBuilder(
         :param sources: -
         :param id_prefix: -
         '''
-        jsii.create(SourceActionBuilder, self, [scope, sources, id_prefix])
+        jsii.create(self.__class__, self, [scope, sources, id_prefix])
 
     @jsii.member(jsii_name="createPipelineSources")
     def create_pipeline_sources(self) -> typing.List[SourceAction]:
@@ -923,7 +923,7 @@ class SsmUpdateConstruct(
         :param sns_topic: -
         :param pipeline_config: -
         '''
-        jsii.create(SsmUpdateConstruct, self, [scope, id, sns_topic, pipeline_config])
+        jsii.create(self.__class__, self, [scope, id, sns_topic, pipeline_config])
 
 
 @jsii.data_type(
